===========
SymPy 0.6.6
===========

20 Dec 2009

* many documentation improvements, including docstrings and doctests
* new assumptions system (See assumptions documentation for more information or have a look at Fabian's blog.)
* improvements to test runner
* printing improvements (especially LaTeX, but also mathml and pretty printing)
* discriminant of polys
* block diagonal methods for matrices
* vast improvements to solving of ODEs (See ODE documentation for full details or Aaron's blog).
* logcombine function
* improvements to sets
* better trigonometric simplification
* improvements to piecewise functions
* improvements to solve() and nsolve()
* improvements to as_numer_denom()
* much better quartic and cubic polynomial rootfinding
* code refactoring and cleanup
* physics: coupled clusters and wick expansion
* matrices: symbolic QR solving
* mpmath updated
* pyglet updated
* many, many bug fixes and small improvements
